@@ -40,7 +40,6 @@ class ShellTest(test_utils.TestCase):
         'MANILA_USERNAME': 'username',
         'MANILA_PASSWORD': 'password',
         'MANILA_PROJECT_ID': 'project_id',
-        'OS_SHARE_API_VERSION': '2.5',
         'MANILA_URL': 'http://no.where',
     }
 
@@ -147,9 +146,30 @@ class ShellTest(test_utils.TestCase):
             self.run_command('list --name' + separator + '1234')
             self.assert_called('GET', '/shares/detail?name=1234')
 
+    @mock.patch.object(cliutils, 'print_list', mock.Mock())
     def test_list_all_tenants_only_key(self):
         self.run_command('list --all-tenants')
         self.assert_called('GET', '/shares/detail?all_tenants=1')
+        cliutils.print_list.assert_called_once_with(
+            mock.ANY,
+            ['ID', 'Name', 'Size', 'Share Proto', 'Status', 'Is Public',
+             'Share Type Name', 'Host', 'Availability Zone', 'Project ID'])
+
+    @mock.patch.object(cliutils, 'print_list', mock.Mock())
+    def test_list_select_column_and_all_tenants(self):
+        self.run_command('list --columns ID,Name --all-tenants')
+        self.assert_called('GET', '/shares/detail?all_tenants=1')
+        cliutils.print_list.assert_called_once_with(
+            mock.ANY,
+            ['Id', 'Name'])
+
+    @mock.patch.object(cliutils, 'print_list', mock.Mock())
+    def test_list_select_column_and_public(self):
+        self.run_command('list --columns ID,Name --public')
+        self.assert_called('GET', '/shares/detail?is_public=True')
+        cliutils.print_list.assert_called_once_with(
+            mock.ANY,
+            ['Id', 'Name'])
 
     def test_list_all_tenants_key_and_value_1(self):
         for separator in self.separators:
@@ -452,7 +472,8 @@ class ShellTest(test_utils.TestCase):
             'Is Public',
             'Share Type Name',
             'Host',
-            'Availability Zone'
+            'Availability Zone',
+            'Project ID'
         ]
         self.run_command('list --public')
         self.assert_called('GET', '/shares/detail?is_public=True')
@@ -609,9 +630,13 @@ class ShellTest(test_utils.TestCase):
             mock.ANY,
             ['Id', 'Name'])
 
+    @mock.patch.object(cliutils, 'print_list', mock.Mock())
     def test_list_snapshots_all_tenants_only_key(self):
         self.run_command('snapshot-list --all-tenants')
         self.assert_called('GET', '/snapshots/detail?all_tenants=1')
+        cliutils.print_list.assert_called_once_with(
+            mock.ANY,
+            ['ID', 'Share ID', 'Status', 'Name', 'Share Size', 'Project ID'])
 
     def test_list_snapshots_all_tenants_key_and_value_1(self):
         for separator in self.separators:
